@@ -1,5 +1,5 @@
 package JSON::Conditional;
-use 5.006; use strict; use warnings; our $VERSION = '1.00';
+use 5.006; use strict; use warnings; our $VERSION = '1.01';
 use JSON; use base 'Struct::Conditional';
 
 our $JSON;
@@ -24,7 +24,7 @@ sub encode_file {
 
 sub decode {
 	if ( $_[1] !~ m/\n/ && -f $_[1]) {
-		$_[0]->decode_file($_[1]);
+		return $_[0]->decode_file($_[1]);
 	} 
 	$JSON->decode($_[1]);
 }
@@ -57,7 +57,7 @@ JSON::Conditional - A conditional language within a JSON struct
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =cut
 
